@@ -8,11 +8,13 @@ use serde::Deserialize;
 
 use crate::cmd::sort::iter_cmp;
 
-static USAGE: &str = "
+static USAGE: &str = r#"
 Dedups CSV rows. 
 
 Note that this requires reading all of the CSV data into memory, because the rows need to be sorted first.
 
+A duplicate count will be sent to <stderr>.
+
 Usage:
     qsv dedup [options] [<input>]
 
@@ -23,6 +25,7 @@ sort options:
                                See 'qsv select --help' for the format details.
     -C, --no-case              Compare strings disregarding case
     -D, --dupes-output <file>  Write duplicates to <file>.
+    -H, --human-readable       Comma separate duplicate count.
 
 Common options:
     -h, --help                 Display this message
@@ -33,7 +36,7 @@ Common options:
                                appear as the header row in the output.
     -d, --delimiter <arg>      The field delimiter for reading CSV data.
                                Must be a single character. (default: ,)
-";
+"#;
 
 #[derive(Deserialize)]
 struct Args {
@@ -44,6 +47,7 @@ struct Args {
     flag_output: Option<String>,
     flag_no_headers: bool,
     flag_delimiter: Option<Delimiter>,
+    flag_human_readable: bool,
 }
 
 pub fn run(argv: &[&str]) -> CliResult<()> {
@@ -66,6 +70,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     let sel = rconfig.selection(&headers)?;
 
     let mut new: Vec<_> = vec![];
+    let mut dupe_count = 0_usize;
     {
         let mut all = rdr.byte_records().collect::<Result<Vec<_>, _>>()?;
         all.sort_by(|r1, r2| {
@@ -81,13 +86,19 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
             if no_case {
                 if iter_cmp_no_case(a, b) != cmp::Ordering::Equal {
                     new.push(all[current].clone());
-                } else if dupes_output {
-                    dupewtr.write_byte_record(&all[current])?;
+                } else {
+                    dupe_count += 1;
+                    if dupes_output {
+                        dupewtr.write_byte_record(&all[current])?;
+                    }
                 }
             } else if iter_cmp(a, b) != cmp::Ordering::Equal {
                 new.push(all[current].clone());
-            } else if dupes_output {
-                dupewtr.write_byte_record(&all[current])?;
+            } else {
+                dupe_count += 1;
+                if dupes_output {
+                    dupewtr.write_byte_record(&all[current])?;
+                }
             }
             current += 1;
         }
@@ -99,6 +110,15 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     for r in new {
         wtr.write_byte_record(&r)?;
     }
+
+    if args.flag_human_readable {
+        use thousands::Separable;
+
+        eprintln!("{}", dupe_count.separate_with_commas());
+    } else {
+        eprintln!("{dupe_count}");
+    }
+
     Ok(wtr.flush()?)
 }
 
