@@ -1,5 +1,6 @@
-use crate::regex::bytes::RegexBuilder;
+use regex::bytes::RegexBuilder;
 use std::borrow::Cow;
+use std::env;
 
 use crate::config::{Config, Delimiter};
 use crate::select::SelectColumns;
@@ -21,6 +22,10 @@ Usage:
     qsv replace [options] <pattern> <replacement> [<input>]
     qsv replace --help
 
+replace arguments:
+    <pattern>              Regular expression to match.
+    <replacement>          Replacement string. Set to '<NULL>' if you want to
+                           replace matches with ''.
 replace options:
     -i, --ignore-case      Case insensitive search. This is equivalent to
                            prefixing the regex with '(?i)'.
@@ -53,13 +58,23 @@ struct Args {
     flag_ignore_case: bool,
 }
 
+const NULL_VALUE: &str = "<NULL>";
+
 pub fn run(argv: &[&str]) -> CliResult<()> {
     let args: Args = util::get_args(USAGE, argv)?;
+    let regex_unicode = match env::var("QSV_REGEX_UNICODE") {
+        Ok(_) => true,
+        Err(_) => args.flag_unicode,
+    };
     let pattern = RegexBuilder::new(&*args.arg_pattern)
         .case_insensitive(args.flag_ignore_case)
-        .unicode(args.flag_unicode)
+        .unicode(regex_unicode)
         .build()?;
-    let replacement = args.arg_replacement.as_bytes();
+    let replacement = if args.arg_replacement == NULL_VALUE {
+        "".as_bytes()
+    } else {
+        args.arg_replacement.as_bytes()
+    };
     let rconfig = Config::new(&args.arg_input)
         .delimiter(args.flag_delimiter)
         .no_headers(args.flag_no_headers)
